#
# Configure paths and flags for the TravelCCM library.
# Denis Arnaud <denis_arnaud at users dot sourceforge dot net>, July 2008
#
# Note: the TRAVELCCM library depends upon BOOST to build.
# Your configure.ac must therefore define appropriately the BOOST
# variables (i.e., BOOST_CFLAGS, BOOST_LIBS, BOOST_DATE_TIME_LIB).
#
# Variables set by this macro:
#  * TRAVELCCM_VERSION
#  * TRAVELCCM_CFLAGS
#  * TRAVELCCM_LIBS
#  * TRAVELCCM_SAMPLE_DIR
#

AC_DEFUN([AM_PATH_TRAVELCCM],
[
AC_LANG_SAVE
AC_LANG([C++])

##
AC_ARG_WITH(travelccm,
	[ --with-travelccm=PFX Prefix where TravelCCM is installed (optional) ],
	    travelccm_dir="$withval",
	    travelccm_dir="")

  if test "x${TRAVELCCM_CONFIG+set}" != xset ; then
     if test "x$travelccm_dir" != x ; then
         TRAVELCCM_CONFIG="$travelccm_dir/bin/travelccm-config"
     fi
  fi

  AC_PATH_PROG(TRAVELCCM_CONFIG, travelccm-config, no)

  ## Check whether Boost flags and libraries are defined
  # General Boost compilation flags
  AC_MSG_CHECKING(for BOOST_CFLAGS environment variable)
  if test x"${BOOST_CFLAGS}" = x; then
	AC_MSG_RESULT([Warning: TravelCCM needs Boost, and the BOOST_CFLAGS environment variable does not appear to be set. It may not be a problem, though, if your Unix distribution is standard, that is, if Boost is installed in /usr. Otherwise, the TravelCCM will fail to compile.])
  else
	AC_MSG_RESULT([ok (set to ${BOOST_CFLAGS})])
  fi

  # Boost Date-Time library
  AC_MSG_CHECKING(for BOOST_DATE_TIME_LIB environment variable)
  if test x"${BOOST_DATE_TIME_LIB}" = x; then
	AC_MSG_RESULT([Warning: TravelCCM needs the Boost Date-Time library, and the BOOST_DATE_TIME_LIB environment variable does not appears to be set. The TravelCCM may fail to link.])
  else
	AC_MSG_RESULT([ok (set to ${BOOST_DATE_TIME_LIB})])
  fi

  # Boost Program Options library
  AC_MSG_CHECKING(for BOOST_PROGRAM_OPTIONS_LIB environment variable)
  if test x"${BOOST_PROGRAM_OPTIONS_LIB}" = x; then
	AC_MSG_RESULT([Warning: TravelCCM needs the Boost Program Options library, and the BOOST_PROGRAM_OPTIONS_LIB environment variable does not appears to be set. The TravelCCM may fail to link.])
  else
	AC_MSG_RESULT([ok (set to ${BOOST_PROGRAM_OPTIONS_LIB})])
  fi

  # Boost File System library
  AC_MSG_CHECKING(for BOOST_FILESYSTEM_LIB environment variable)
  if test x"${BOOST_FILESYSTEM_LIB}" = x; then
	AC_MSG_RESULT([Warning: TravelCCM needs the Boost Date-Time library, and the BOOST_FILESYSTEM_LIB environment variable does not appears to be set. The TravelCCM may fail to link.])
  else
	AC_MSG_RESULT([ok (set to ${BOOST_FILESYSTEM_LIB})])
  fi

  ## TravelCCM version
  min_travelccm_version=ifelse([$1], ,0.1.0,$1)
  AC_MSG_CHECKING(for TravelCCM - version >= $min_travelccm_version)
  no_travelccm=""
  if test "${TRAVELCCM_CONFIG}" = "no" ; then
     no_travelccm=yes
     AC_MSG_RESULT([no])
  else
     TRAVELCCM_VERSION=`${TRAVELCCM_CONFIG} --version`
     TRAVELCCM_CFLAGS=`${TRAVELCCM_CONFIG} --cflags`
     TRAVELCCM_CFLAGS="${BOOST_CFLAGS} ${TRAVELCCM_CFLAGS}"
     TRAVELCCM_LIBS=`${TRAVELCCM_CONFIG} --libs`
     TRAVELCCM_LIBS="${BOOST_LIBS} ${BOOST_DATE_TIME_LIB} ${TRAVELCCM_LIBS}"
     TRAVELCCM_SAMPLE_DIR=`${TRAVELCCM_CONFIG} --sampledir`

     AC_SUBST([TRAVELCCM_VERSION])
     AC_SUBST([TRAVELCCM_CFLAGS])
     AC_SUBST([TRAVELCCM_LIBS])
     AC_SUBST([TRAVELCCM_SAMPLE_DIR])

    travelccm_major_version=`echo ${TRAVELCCM_VERSION} | sed 's/^\([[0-9]]*\).*/\1/'`
    if test "x${travelccm_major_version}" = "x" ; then
       travelccm_major_version=0
    fi

    travelccm_minor_version=`echo ${TRAVELCCM_VERSION} | \
						sed 's/^\([[0-9]]*\)\.\{0,1\}\([[0-9]]*\).*/\2/'`
    if test "x${travelccm_minor_version}" = "x" ; then
       travelccm_minor_version=0
    fi

    travelccm_micro_version=`echo ${TRAVELCCM_VERSION} | \
          sed 's/^\([[0-9]]*\)\.\{0,1\}\([[0-9]]*\)\.\{0,1\}\([[0-9]]*\).*/\3/'`
    if test "x${travelccm_micro_version}" = "x" ; then
       travelccm_micro_version=0
    fi

    ## Simple test of compilation and link
    SAVED_CPPFLAGS="${CPPFLAGS}"
    SAVED_LDFLAGS="${LDFLAGS}"
    CPPFLAGS="${CPPFLAGS} ${BOOST_CFLAGS} ${TRAVELCCM_CFLAGS}"
    LDFLAGS="${LDFLAGS} ${TRAVELCCM_LIBS}"


    AC_COMPILE_IFELSE(
		[AC_LANG_PROGRAM([[#include <travelccm/TRAVELCCM_Service.hpp>
				]],
				[[int i=0;]]
		)]
		,

    	[AC_MSG_RESULT([yes (${TRAVELCCM_VERSION})])],

	[AC_MSG_ERROR([We could not compile a simple TravelCCM example. See config.log.])]
    )

    CPPFLAGS="${SAVED_CPPFLAGS}"
    LDFLAGS="${SAVED_LDFLAGS}"

  fi

AC_LANG_RESTORE
])
